class Policy {
  constructor(id, color, lang = "de") {
    this.id = id;
    this.color = color;
    this.lang = lang;
  }
  draw(params) {
    try {
      const root = document.getElementById(this.id);
      const policyBtn = document.createElement("p");
      const backdrop = document.createElement("div");
      const modal = document.createElement("div");
      const modalHeader = document.createElement("div");
      const modalTitle = document.createElement("p");
      const closeBtn = document.createElement("span");
      const modalContent = document.createElement("div");

      root.style.padding = "30px 0";
      root.style.position = "relative";
      root.style.zIndex = 999;

      policyBtn.innerText = _langs[this.lang].policyBtn;
      policyBtn.style.textAlign = "center";
      policyBtn.style.color = this.color == "white" ? "#fff" : "#000";
      policyBtn.style.cursor = "pointer";
      policyBtn.style.fontSize = "14px";

      backdrop.style.height = "100vh";
      backdrop.style.width = "100vw";
      backdrop.style.position = "fixed";
      backdrop.style.top = 0;
      backdrop.style.background = "rgba(0,0,0,0.7)";
      backdrop.style.zIndex = 1000;
      backdrop.style.overflow = "hidden";
      backdrop.style.display = "flex";
      backdrop.style.justifyContent = "center";
      backdrop.style.alignItems = "center";

      modal.style.maxWidth = "700px";
      modal.style.width = "100%";
      modal.style.margin = "15px";
      modal.style.background = "#fff";
      modal.style.borderRadius = "10px";
      modal.style.boxShadow = "0 5px 15px rgb(0 0 0 / 50%)";
      modal.style.minHeight = "300px";
      modal.style.maxHeight = "90vh";
      modal.style.paddingBottom = "15px";

      modalHeader.style.padding = "15px";
      modalHeader.style.borderBottom = "1px solid #e5e5e5";
      modalHeader.style.display = "flex";
      modalHeader.style.justifyContent = "space-between";
      modalHeader.style.alignItems = "center";

      modalTitle.innerText = _langs[this.lang].policyBtn;
      modalTitle.style.fontSize = "14px";
      modalTitle.style.textTransform = "uppercase";
      modalTitle.style.textAlign = "left";
      modalTitle.style.color = "#000";
      modalTitle.style.margin = 0;

      modalContent.style.padding = "15px";
      modalContent.style.overflowY = "scroll";
      modalContent.style.maxHeight = "70vh";
      modalContent.style.fontSize = "16px";
      modalContent.style.textAlign = "left";
      modalContent.style.color = "#000";

      closeBtn.style.height = "24px";
      closeBtn.style.width = "24px";
      closeBtn.style.background =
        "url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e\")";
      closeBtn.style.backgroundSize = "14px";
      closeBtn.style.backgroundRepeat = "no-repeat";
      closeBtn.style.backgroundPosition = "center";
      closeBtn.style.cursor = "pointer";
      root.appendChild(policyBtn);

      modalContent.innerHTML = _langs[this.lang].policyContent;

      backdrop.appendChild(modal);
      modal.appendChild(modalHeader);
      modalHeader.appendChild(modalTitle);
      modalHeader.appendChild(closeBtn);
      modal.appendChild(modalContent);
      policyBtn.addEventListener("click", () => {
        document.body.appendChild(backdrop);
        document.body.style.overflow = "hidden";
      });
      closeBtn.addEventListener("click", () => {
        document.body.removeChild(backdrop);
        document.body.style.overflow = "auto";
      });
    } catch (e) {
      console.log(e);
    }
  }
}

const _langs = {
  de: {
    policyBtn: "DATENSCHUTZERKLÄRUNG",
    policyContent: `ALLGEMEINE INFORMATIONEN <br><br>
        Wir erheben personenbezogene Daten ('Informationen'), die wir von Ihnen per E-Mail und aus den von Ihnen ausgefüllten Anmeldefragebogen erhalten.
        <br> Diese Datenschutzrichtlinie ist ein integraler Bestandteil der Nutzungsvereinbarung und der Einwilligung zur Verarbeitung personenbezogener Daten.
        <br>   Wir erheben auch Daten, wenn Sie sich freiwillig an Umfragen beteiligen, zu denen wir Sie einladen, oder wenn Sie Feedback, Kommentare oder andere Informationen auf unserer Webseite hinterlassen.
        <br>   Wenn der Anmeldevorgang nicht erfolgreich abgeschlossen wurde, speichern wir keine Informationen über Sie, außer den begrenzten Informationen, die notwendig sind, um Betrug oder missbräuchliche Nutzung zu verhindern.
        <br>  Sie sind nicht verpflichtet, alle Fragen zu beantworten; in solchen Fällen besteht immer die Option 'Ich enthalte mich der Antwort'. Die Antworten auf diese Fragen werden vertraulich behandelt, es sei denn, Sie erklären sich offen und ausdrücklich damit einverstanden, dass Ihre Antworten auf diese Fragen zusammen mit Ihren persönlichen Daten an die Auftraggeber der Studie zur weiteren Analyse weitergeleitet werden.
        <br><br>   WARUM WIR INFORMATIONEN ÜBER SIE ERHEBEN
        <br><br> Der Hauptzweck der Erhebung von Informationen über Sie ist die Marktforschung. Wenn Sie uns beitreten, schließen wir einen Vertrag mit Ihnen ab, der dieser Datenschutzrichtlinie sowie unseren Regeln unterliegt. 
        <br> Um diesen Vertrag zu erfüllen, indem wir Sie zu relevanten Fragen einladen, müssen wir Informationen sammeln, verarbeiten und klassifizieren, die zum Zeitpunkt der Anwerbung neuer Teilnehmer angefordert werden oder die Sie zu einem späteren Zeitpunkt Ihrem Profil auf der Webseite hinzufügen können oder die wir in Übereinstimmung mit dieser Datenschutzrichtlinie sammeln und mit automatischen Mitteln verarbeiten. Diese Informationen werden auch benötigt, um Ihnen Auszeichnungen zukommen zu lassen und um Sie bezüglich von Umfragen zu kontaktieren.
        <br> <br> Darüber hinaus erheben wir Informationen von Ihnen mit Ihrer Darüber hinaus erheben wir Informationen von Ihnen mit Ihrer Zustimmung, insbesondere wenn Sie auf Einladungen zur Teilnahme an Umfragen antworten, die wir Ihnen zusenden können, oder wenn Sie sie in anderen Fällen freiwillig zur Verfügung stellen. Ihre Antworten auf solche Umfragen sind Ihre Entscheidung. In einigen Situationen können wir Ihre zusätzliche oder sogar ausdrückliche Zustimmung verlangen, wenn dies angemessen oder notwendig ist.
        <br> Wie verwenden wir die Informationen, die wir von Ihnen erhalten?
        <br><br> Wir verwenden die Informationen, die wir von Ihnen erhalten, um
        <br> - Alle Panelteilnehmer zu erfassen und anonyme Profile auf der Grundlage der von Ihnen bereitgestellten Informationen zu erstellen.
        <br>  - Ihnen Einladungen zur Teilnahme an Umfragen zu schicken, die Sie aufgrund der Informationen, die Sie in Ihrem Anmeldefragebogen angegeben oder eventuell zu einem späteren Zeitpunkt aktualisiert haben, interessieren könnten;
        <br>  - Wenn Sie ausdrücklich und gesondert zugestimmt haben, bevor Ihre Daten an den Auftraggeber weitergegeben werden, kann der Auftraggeber diese Daten auch dazu verwenden, Sie zu kontaktieren, um Sie zur Teilnahme an weiteren von ihm durchzuführenden Forschungen einzuladen
        <br>  - Wenn Ihre Zustimmung vorliegt, Ihre Daten an andere Partner von "OL EG media" weiterzugeben
        <br> - Wir werden alle angemessenen Maßnahmen ergreifen, um sicherzustellen, dass alle von uns verarbeiteten personenbezogenen Daten korrekt, angemessen, relevant und nicht übermäßig sind, unter Berücksichtigung des Zwecks, für den sie erhoben wurden. Wir werden die für einen bestimmten Zweck erhobenen personenbezogenen Daten nicht für andere, nicht damit zusammenhängende Zwecke verwenden, es sei denn, Sie haben Ihre Zustimmung gegeben.
        <br> <br>  - Wir verwenden Ihre Daten IMMER nur zu Forschungszwecken und in Übereinstimmung mit diesen Regeln. Wir werden NICHT versuchen, Ihnen etwas zu verkaufen oder Ihre Informationen für Marketingzwecke zu verwenden, es sei denn, dies steht im Zusammenhang mit dem Zweck dieses Panels (z. B. Teilnahme an weiteren Umfragen). Unter keinen Umständen werden Informationen über Sie zu Marketing- oder Werbezwecken an Dritte weitergegeben.
        <br>  Verwendung von Cookies oder ähnlichem Code
        <br> <br> Indem Sie unserem Panel beitreten und an unserer Online-Forschung teilnehmen, erklären Sie sich damit einverstanden, dass wir Cookies und ähnliche Technologien ('Cookies') verwenden und für die Dauer Ihrer Teilnahme an unseren Online-Forschungen Informationen von Ihrem Computer/Laptop oder einem anderen Gerät sammeln.
        <br> Die Website unseres Panels und die Online-Umfragen sammeln Informationen mithilfe von Cookies und ähnlichen Technologien. Das sind kleine Dateien, die auf Ihrem Computer gespeichert werden. 
        <br> <br> Die E-Mails, die wir an mögliche neue Panelteilnehmer senden, setzen ebenfalls ein Cookie, wenn Bilder heruntergeladen und E-Mails geöffnet werden. Sie können das Setzen von Cookies verhindern, indem Sie die E-Mail nur als Text öffnen, die E-Mail vor dem Hochladen von Bildern schließen oder die Einstellungen der Software Ihres Browsers bzw. Ihrer E-Mail so ändern, dass Cookies nicht zugelassen werden.
        <br> Basis-Cookies
        <br><br> Basis-Cookies, die für dieses Panel verwendet werden können:
        <br> balancerNode - wird intern für den Lastausgleich verwendet
        <br> token - wird verwendet, um Sie von anderen Nutzern der Website zu unterscheiden
        <br> sessionId - dient zur Identifizierung der aktuellen Sitzung
        <br> <br> Cookies von Dritten können auch von anderen Unternehmen gesetzt werden.
        <br> Wie können Sie auf Ihre Daten zugreifen und/oder sie korrigieren und/oder ihre Übertragung und/oder Löschung beantragen?
        <br> <br>  Sie haben das Recht, eine Kopie aller Informationen über Sie zu verlangen, die wir speichern. Sie haben das Recht, uns aufzufordern, Informationen über Sie zu korrigieren, die wir speichern. Sie haben auch das Recht, uns aufzufordern, alle Informationen, die Sie uns bereitgestellt haben, an eine andere Partei zu übermitteln. In vielen Fällen haben Sie auch das Recht, die Löschung Ihrer persönlichen Daten zu verlangen, die wir speichern.
        <br>  In all diesen Fällen wenden Sie sich bitte an unsere Datenschutzabteilung. Sie können sie wie folgt kontaktieren:
        <br>  Senden Sie eine E-Mail mit einer Anfrage an die folgende Adresse: info@olegmedia.live
        `,
  },
  en: {
    policyBtn: "Privacy Policy",
    policyContent: `GENERAL INFORMATION<br><br>
        We collect personal data ("information") from you through emails and the registration forms that you fill out.
        <br> This privacy policy is an integral part of the user agreement and consent to process personal data.
        <br>   We also collect data when you voluntarily participate in surveys that we invite you to, or when you leave feedback, comments, or other information on our panelist website.
        <br>  If the registration process was not successfully completed, we do not store any information about you, except for the limited information necessary to prevent fraud or misuse.
        <br>You are not obligated to answer all questions; in such cases, there's always the option 'I refrain from answering'. The responses to these questions are treated confidentially, unless you openly and explicitly agree that your responses to these questions, together with your personal data, are forwarded to the study clients for further in-depth analysis.
        <br><br> WHY WE COLLECT INFORMATION ABOUT YOU
        <br><br> The primary purpose of collecting information about you is market research. When you join us, we enter into a contract with you that is subject to this privacy policy and our rules.
        <br> To fulfil this contract by inviting you to relevant questions, we need to collect, process, and classify information that is requested at the time of recruiting new participants or that you can add to your profile on the panelist website at a later date, or that we collect in accordance with this privacy policy and process using automated means. This information is also needed to award you and to contact you about surveys. This issue is explained in detail in our rules.
        <br> <br>  In addition, we collect information from you with your consent, particularly when you respond to survey invitations that we may send to you, or when you voluntarily provide it in other cases. Your responses to such surveys are your decision. In some situations, we may ask for your additional or even explicit consent, when it is appropriate or necessary. The activity in general and the operation of the panel are described in more detail in our rules.
        <br> How do we use the information we receive from you?
        <br><br> We use the information we receive from you to:
        <br> - record all panelists and create anonymous profiles based on the information you provide.
        <br>  - send you invitations to participate in surveys that you match according to the information you provided in your registration form or may have updated at a later date;
        <br>  - If you have expressly and separately agreed before your data is passed on to the client, the client may also use this data to contact you to invite you to participate in further research they are conducting
        <br>  - If your consent is given, to pass your data on to other partners of "OL EG media"
        <br>  We will take all reasonable steps to ensure that all personal data we process is accurate, adequate, relevant, and not excessive, taking into account the purpose for which it was collected. We will not use personal data collected for a specific purpose for other, unrelated purposes, unless you have given your consent.
        <br> <br>  - We ALWAYS use your data only for research purposes and in accordance with these rules. We will NOT attempt to sell you anything or use information about you for marketing purposes, unless this is related to the purpose of this panel (e.g. participation in further surveys). Under no circumstances will information about you be passed on to third parties for marketing or advertising purposes.
        <br> Using cookies or similar code?
        <br> <br> By joining our panel and participating in our online research, you agree that we use cookies and similar technologies ("cookies") and collect information from your computer/laptop or other computing device during your participation in our online research, as described below.
        <br> The website of our panel and the online surveys collect information using cookies and functionally similar technologies. These are small files that are stored on your computer.
        <br> <br> The emails we send to potential new panel members also set a cookie when images are downloaded and emails are opened. You can prevent cookies from being set by opening the email as text only, closing the email before downloading images, or changing the settings of your browser or email software to not allow cookies.
        <br> Basic cookies
        <br><br> Basic cookies that may be used for this panel include:
        <br> balancerNode - used internally for load balancing
        <br>  token - used to distinguish you from other users of the website
        <br> sessionId - used to identify the current session
        <br> <br>  Third-party cookies may also be set by other companies.
        <br>  How can you access your data and/or correct it and/or request its transfer and/or deletion?
        <br> <br>  You have the right to request a copy of all information about you that we hold. You have the right to ask us to correct information about you that we hold. You also have the right to pass on all information you have provided to us to another party. In many cases, you also have the right to request the deletion of your personal data that we hold.
        <br>   In all these cases, please contact our data protection department. You can contact them as follows:
        <br>  Send an email with a request to the following address: info@olegmedia.live
        `,
  },
};
